﻿using System.Collections.ObjectModel;
using System.ComponentModel;
using System.Linq;
using System.Windows.Data;
using System.Windows.Input;
using Infragistics.Samples.Framework;
using Infragistics.Samples.Shared.Extensions;
using Infragistics.Windows.DataPresenter;
using Infragistics.Windows.DataPresenter.Events;

namespace IGDataGrid.Samples.Display
{
    public partial class CheckBoxInUnboundField : SampleContainer
    {
        // The CheckBoxes in the XamDataGrid execute this command when clicked.
        public static readonly RoutedCommand ShowInChartCommand = new RoutedCommand();
        CollectionViewSource customerDataSource = new CollectionViewSource();
        CustomerSampleData customerData = new CustomerSampleData();

        public CheckBoxInUnboundField()
        {
            InitializeComponent();
            
            customerDataSource.Source = customerData;
            customerDataSource.SortBy("ID", ListSortDirection.Descending);
            this.xamBarChart.DataContext = customerDataSource.View;
            this.DataContext = customerData.ToArray();

        }
        void XamDataGrid_InitializeRecord(object sender, InitializeRecordEventArgs e)
        {
            // Initialize each ShowInChartCommand cell to true.
            var dataRecord = e.Record as DataRecord;
            if (dataRecord != null && !e.ReInitialize)
                dataRecord.Cells["ShowInChart"].Value = true;
        }
       
        void ShowInChartCommand_CanExecute(object sender, CanExecuteRoutedEventArgs e)
        {
            // The ShowInChartCommand command can execute if the parameter references a Customer.
            e.CanExecute = e.Parameter is Customer;
        }

        void ShowInChartCommand_Executed(object sender, ExecutedRoutedEventArgs e)
        {
            var cust = e.Parameter as Customer;
            if (cust != null)
                this.AddOrRemoveCustomer(cust);
        }
      
        void AddOrRemoveCustomer(Customer cust)
        {
            var dataPoints = customerDataSource.Source as CustomerSampleData;
            if (dataPoints == null) return;

            var dataPoint = dataPoints.FirstOrDefault(dp => dp.Label == cust.Label);
            if (dataPoint == null)
            {
                dataPoint = new Customer
                {
                    ID = cust.ID,
                    TotalSales = cust.TotalSales,
                    Name = cust.Name,
                };
                dataPoints.Add(dataPoint);
            }
            else
            {
                // Remove the customer from the chart.
                dataPoints.Remove(dataPoint);
            }
            customerDataSource.Source = dataPoints;
            customerDataSource.SortBy("ID", ListSortDirection.Descending);
            this.xamBarChart.DataContext = customerDataSource.View;
           
        }
    }

    #region Customer Models
    public class CustomerSampleData : CustomerCollection
    {
        public CustomerSampleData()
        {
            this.Add(new Customer(1, "Jacob Martin", 10993.93));
            this.Add(new Customer(2, "Sally Feldman", 3112.01));
            this.Add(new Customer(3, "Franklin Longrow", 5232.95));
            this.Add(new Customer(4, "Dr. Samuel Smith", 9123.24));
            this.Add(new Customer(5, "Wilma Norrington", 7009.34));
        }
    }
    public class CustomerCollection : ObservableCollection<Customer>
    {
    }
    public class Customer
    {
        public Customer()
        {
            
        }
        public Customer(int id, string name, double totalSales)
        {
            this.ID = id;
            this.Name = name;
            this.TotalSales = totalSales;
        }

        public int ID { get; set; }
        public string Label { get { return "Customer #" + this.ID;  } }
        public string Name { get; set; }
        public double TotalSales { get; set; }
    }

    #endregion  
}
